@@ -1,19 +1,3 @@
-# This file is part of CairoSVG
-# Copyright © 2010-2018 Kozea
-#
-# This library is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 3 of the License, or (at your option) any
-# later version.
-#
-# This library is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with CairoSVG.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Utils dealing with URLs.
 
@@ -27,7 +11,7 @@ from urllib.request import Request, urlopen
 
 from . import VERSION
 
-HTTP_HEADERS = {'User-Agent': 'CairoSVG {}'.format(VERSION)}
+HTTP_HEADERS = {'User-Agent': f'CairoSVG {VERSION}'}
 
 URL = re.compile(r'url\((.+)\)')
 
@@ -100,6 +84,17 @@ def fetch(url, resource_type):
     return urlopen(Request(url, headers=HTTP_HEADERS)).read()
 
 
+def safe_fetch(url, resource_type):
+    """Fetch the content of ``url`` only if it’s a data-URL.
+
+    Otherwise, return an empty SVG.
+
+    """
+    if url and url.startswith('data:'):
+        return fetch(url, resource_type)
+    return b'<svg width="1" height="1"></svg>'
+
+
 def parse_url(url, base=None):
     """Parse an URL.
 
@@ -137,7 +132,7 @@ def parse_url(url, base=None):
                     else:
                         url = ''
                     if parsed_url.fragment:
-                        url = '{}#{}'.format(url, parsed_url.fragment)
+                        url = f'{url}#{parsed_url.fragment}'
             elif parsed_url.scheme in ('', parsed_base.scheme):
                 # `urljoin` automatically uses the "folder" part of `base`
                 url = urljoin(base, url)
@@ -153,7 +148,7 @@ def read_url(url, url_fetcher, resource_type):
     if url.scheme:
         url = url.geturl()
     else:
-        url = 'file://{}'.format(os.path.abspath(url.geturl()))
+        url = f'file://{os.path.abspath(url.geturl())}'
         url = normalize_url(url)
 
     return url_fetcher(url, resource_type)
